==> ssp-center-api-0.5.41-20190729.021326-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqMaterialSpecificationDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/20
 */
public class ReqMaterialSpecificationDto extends BaseQueryDto {

    private static final long                     serialVersionUID = -2895639812707869977L;

    private Long                                  id;                                      // 规格ID
    private String                                title;                                   // 规格标题
    private String                                description;                             // 规格描述
    private String                                schematicImg;                            // 示意图
    private Integer                               isDirect;                                // 是否定向
    private List<RspMaterialSpecificationItemDto> itemDtoList;                             // 素材列表

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSchematicImg() {
        return schematicImg;
    }

    public void setSchematicImg(String schematicImg) {
        this.schematicImg = schematicImg;
    }

    public Integer getIsDirect() {
        return isDirect;
    }

    public void setIsDirect(Integer isDirect) {
        this.isDirect = isDirect;
    }

    public List<RspMaterialSpecificationItemDto> getItemDtoList() {
        return itemDtoList;
    }

    public void setItemDtoList(List<RspMaterialSpecificationItemDto> itemDtoList) {
        this.itemDtoList = itemDtoList;
    }
}

==> ssp-center-api-1.2.88-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqMaterialSpecificationDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/20
 */
public class ReqMaterialSpecificationDto extends BaseQueryDto {

    private static final long                     serialVersionUID = -2895639812707869977L;

    private Long                                  id;                                      // 规格ID
    private Long                                  msId;                                      // 规格ID
    private String                                title;                                   // 规格标题
    private String                                description;                             // 规格描述
    private String                                schematicImg;                            // 示意图
    private Integer                               isDirect;                                // 是否定向
    private List<RspMaterialSpecificationItemDto> itemDtoList;                             // 素材列表

    /** 宽高 **/
    private Integer                                imageWidth;
    private Integer                                imageHeight;

    /**
     * 是否标准规格 0：非标准，1：标准
     */
    private Integer isStandard;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getSchematicImg() {
        return schematicImg;
    }

    public void setSchematicImg(String schematicImg) {
        this.schematicImg = schematicImg;
    }

    public Integer getIsDirect() {
        return isDirect;
    }

    public void setIsDirect(Integer isDirect) {
        this.isDirect = isDirect;
    }

    public List<RspMaterialSpecificationItemDto> getItemDtoList() {
        return itemDtoList;
    }

    public void setItemDtoList(List<RspMaterialSpecificationItemDto> itemDtoList) {
        this.itemDtoList = itemDtoList;
    }

    public Integer getIsStandard() {
        return isStandard;
    }

    public void setIsStandard(Integer isStandard) {
        this.isStandard = isStandard;
    }


    public Integer getImageWidth() {
        return imageWidth;
    }

    public void setImageWidth(Integer imageWidth) {
        this.imageWidth = imageWidth;
    }

    public Integer getImageHeight() {
        return imageHeight;
    }

    public void setImageHeight(Integer imageHeight) {
        this.imageHeight = imageHeight;
    }

    public Long getMsId() {
        return msId;
    }

    public void setMsId(Long msId) {
        this.msId = msId;
    }
}
